==> estateplat-common-1.2.3-20180528.211252-98-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmhtQqwygl.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:zhangguangguang@gtmap.cn">zhangguangguang</a>
 * @version 1.0, 2018/04/20
 * @description    前期物业管理历史表(第九章)
 */
@Table(name = "fcjy_xjspf_ba_mmht_qqwygl")
public class FcjyXjspfBaMmhtQqwygl {
    @Id
    private String gllsid;//主键
    private String htlsid;//合同历史表id
    private String glid;//前期物业管理表(第九章)主键
    private String htid;//合同ID
    private String wymc;//物业名称
    private String zzzh;//资质证号
    private String sffs;//收费方式
    private Double wyfjg;//物业费价格（元）
    private String wyfgc;//物业费构成
    private String wyfwqsrq;//物业服务起始日期
    private String wyfwzzrq;//物业服务终止日期
    private Date lssj;//历史时间
    private Integer lscs;//历史次数

    public String getGllsid() {
        return gllsid;
    }

    public void setGllsid(String gllsid) {
        this.gllsid = gllsid;
    }

    public String getHtlsid() { return htlsid; }

    public void setHtlsid(String htlsid) { this.htlsid = htlsid; }

    public String getGlid() {
        return glid;
    }

    public void setGlid(String glid) {
        this.glid = glid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getWymc() {
        return wymc;
    }

    public void setWymc(String wymc) {
        this.wymc = wymc;
    }

    public String getZzzh() {
        return zzzh;
    }

    public void setZzzh(String zzzh) {
        this.zzzh = zzzh;
    }

    public String getSffs() {
        return sffs;
    }

    public void setSffs(String sffs) {
        this.sffs = sffs;
    }

    public Double getWyfjg() {
        return wyfjg;
    }

    public void setWyfjg(Double wyfjg) {
        this.wyfjg = wyfjg;
    }

    public String getWyfgc() {
        return wyfgc;
    }

    public void setWyfgc(String wyfgc) {
        this.wyfgc = wyfgc;
    }

    public String getWyfwqsrq() {
        return wyfwqsrq;
    }

    public void setWyfwqsrq(String wyfwqsrq) {
        this.wyfwqsrq = wyfwqsrq;
    }

    public String getWyfwzzrq() {
        return wyfwzzrq;
    }

    public void setWyfwzzrq(String wyfwzzrq) {
        this.wyfwzzrq = wyfwzzrq;
    }

    public Date getLssj() { return lssj;}

    public void setLssj(Date lssj) { this.lssj = lssj;}

    public Integer getLscs() { return lscs; }

    public void setLscs(Integer lscs) { this.lscs = lscs; }
}

==> estateplat-common-1.2.3-20180612.083341-113-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmhtQqwygl.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:zhangguangguang@gtmap.cn">zhangguangguang</a>
 * @version 1.0, 2018/04/20
 * @description    前期物业管理历史表(第九章)
 */
@Table(name = "fcjy_xjspf_ba_mmht_qqwygl")
public class FcjyXjspfBaMmhtQqwygl implements Serializable {
    @Id
    private String gllsid;//主键
    private String htlsid;//合同历史表id
    private String glid;//前期物业管理表(第九章)主键
    private String htid;//合同ID
    private String wymc;//物业名称
    private String zzzh;//资质证号
    private String sffs;//收费方式
    private Double wyfjg;//物业费价格（元）
    private String wyfgc;//物业费构成
    private String wyfwqsrq;//物业服务起始日期
    private String wyfwzzrq;//物业服务终止日期
    private Date lssj;//历史时间
    private Integer lscs;//历史次数

    public String getGllsid() {
        return gllsid;
    }

    public void setGllsid(String gllsid) {
        this.gllsid = gllsid;
    }

    public String getHtlsid() { return htlsid; }

    public void setHtlsid(String htlsid) { this.htlsid = htlsid; }

    public String getGlid() {
        return glid;
    }

    public void setGlid(String glid) {
        this.glid = glid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getWymc() {
        return wymc;
    }

    public void setWymc(String wymc) {
        this.wymc = wymc;
    }

    public String getZzzh() {
        return zzzh;
    }

    public void setZzzh(String zzzh) {
        this.zzzh = zzzh;
    }

    public String getSffs() {
        return sffs;
    }

    public void setSffs(String sffs) {
        this.sffs = sffs;
    }

    public Double getWyfjg() {
        return wyfjg;
    }

    public void setWyfjg(Double wyfjg) {
        this.wyfjg = wyfjg;
    }

    public String getWyfgc() {
        return wyfgc;
    }

    public void setWyfgc(String wyfgc) {
        this.wyfgc = wyfgc;
    }

    public String getWyfwqsrq() {
        return wyfwqsrq;
    }

    public void setWyfwqsrq(String wyfwqsrq) {
        this.wyfwqsrq = wyfwqsrq;
    }

    public String getWyfwzzrq() {
        return wyfwzzrq;
    }

    public void setWyfwzzrq(String wyfwzzrq) {
        this.wyfwzzrq = wyfwzzrq;
    }

    public Date getLssj() { return lssj;}

    public void setLssj(Date lssj) { this.lssj = lssj;}

    public Integer getLscs() { return lscs; }

    public void setLscs(Integer lscs) { this.lscs = lscs; }
}
